==> jc-1.4.0.tar.gz: javax/swing/text/AbstractDocument__24ElementEdit.h <==
// public class javax.swing.text.AbstractDocument$ElementEdit

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b10102c3d3e7a8eb javax_swing_text_AbstractDocument__24ElementEdit
// @dep_class 61d010fed23a29ad javax_swing_undo_AbstractUndoableEdit

// header file dependencies
// @dep_header javax_swing_undo_AbstractUndoableEdit

#include "javax/swing/undo/AbstractUndoableEdit.h"

#ifndef _JC_javax_swing_text_AbstractDocument__24ElementEdit_H_
#define _JC_javax_swing_text_AbstractDocument__24ElementEdit_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_text_Element$object;

// Typedefs
typedef struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$sub_refs	_jc_javax_swing_text_AbstractDocument__24ElementEdit$sub_refs;
typedef struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$sub_nonrefs	_jc_javax_swing_text_AbstractDocument__24ElementEdit$sub_nonrefs;
typedef struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$refs	_jc_javax_swing_text_AbstractDocument__24ElementEdit$refs;
typedef struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$nonrefs	_jc_javax_swing_text_AbstractDocument__24ElementEdit$nonrefs;
typedef struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$object	_jc_javax_swing_text_AbstractDocument__24ElementEdit$object;

typedef struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$fields_struct	_jc_javax_swing_text_AbstractDocument__24ElementEdit$fields_struct;
typedef const struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$vmethods	_jc_javax_swing_text_AbstractDocument__24ElementEdit$vmethods;
typedef const struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$vtable	_jc_javax_swing_text_AbstractDocument__24ElementEdit$vtable;
typedef const struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$vtype	_jc_javax_swing_text_AbstractDocument__24ElementEdit$vtype;

// Class fields structure
struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_text_AbstractDocument__24ElementEdit$fields_struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$class_fields;

// Constructors
extern void _jc_javax_swing_text_AbstractDocument__24ElementEdit$method$_init$6bf517a1d9ac8e3f(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$object *, struct _jc_object *, jint, struct _jc_object_array *, struct _jc_object_array *);

// Virtual methods
extern _jc_object_array *_jc_javax_swing_text_AbstractDocument__24ElementEdit$method$getChildrenAdded$d6a053e473b11ce8(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$object *);
extern _jc_object_array *_jc_javax_swing_text_AbstractDocument__24ElementEdit$method$getChildrenRemoved$217236fae35b7e62(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$object *);
extern struct _jc_object *_jc_javax_swing_text_AbstractDocument__24ElementEdit$method$getElement$9ded1b90e4e688d5(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$object *);
extern jint _jc_javax_swing_text_AbstractDocument__24ElementEdit$method$getIndex$71a8f9126346f049(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_AbstractDocument__24ElementEdit$method_info$getChildrenAdded$d6a053e473b11ce8;
extern _jc_method _jc_javax_swing_text_AbstractDocument__24ElementEdit$method_info$getChildrenRemoved$217236fae35b7e62;
extern _jc_method _jc_javax_swing_text_AbstractDocument__24ElementEdit$method_info$getElement$9ded1b90e4e688d5;
extern _jc_method _jc_javax_swing_text_AbstractDocument__24ElementEdit$method_info$getIndex$71a8f9126346f049;

// Virtual methods structure
struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$vmethods {
	_jc_object_array	*(*getChildrenAdded$d6a053e473b11ce8)(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$object *);
	_jc_object_array	*(*getChildrenRemoved$217236fae35b7e62)(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$object *);
	struct _jc_object	*(*getElement$9ded1b90e4e688d5)(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$object *);
	jint	(*getIndex$71a8f9126346f049)(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$object *);
};

// Vtable
struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_undo_AbstractUndoableEdit$vmethods	javax_swing_undo_AbstractUndoableEdit;
	_jc_javax_swing_text_AbstractDocument__24ElementEdit$vmethods	javax_swing_text_AbstractDocument__24ElementEdit;
};

// Vtype
struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$vtype {
	_jc_type			type;
	_jc_javax_swing_text_AbstractDocument__24ElementEdit$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$sub_refs {
	struct _jc_object	*elem;
	_jc_object_array	*removed;
	_jc_object_array	*added;
};

// Reference instance fields (object)
struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$refs {
    _jc_javax_swing_text_AbstractDocument__24ElementEdit$sub_refs	javax_swing_text_AbstractDocument__24ElementEdit;
    _jc_javax_swing_undo_AbstractUndoableEdit$sub_refs	javax_swing_undo_AbstractUndoableEdit;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$sub_nonrefs {
	jint	index;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_undo_AbstractUndoableEdit$sub_nonrefs	javax_swing_undo_AbstractUndoableEdit;
    _jc_javax_swing_text_AbstractDocument__24ElementEdit$sub_nonrefs	javax_swing_text_AbstractDocument__24ElementEdit;
};

// Object instance structure
struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$object {
	_jc_javax_swing_text_AbstractDocument__24ElementEdit$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_AbstractDocument__24ElementEdit$vtype	*vtype;
	_jc_javax_swing_text_AbstractDocument__24ElementEdit$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_AbstractDocument__24ElementEdit$vtype _jc_javax_swing_text_AbstractDocument__24ElementEdit$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_AbstractDocument__24ElementEdit, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_AbstractDocument__24ElementEdit$class_object;

#endif	/* _JC_javax_swing_text_AbstractDocument__24ElementEdit_H_ */

==> jc-1.4.6.tar.gz: javax/swing/text/AbstractDocument__24ElementEdit.h <==
// public class javax.swing.text.AbstractDocument$ElementEdit

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b9da31fca24adcf5 javax_swing_text_AbstractDocument__24ElementEdit
// @dep_class 61d010fed23a29ad javax_swing_undo_AbstractUndoableEdit

// header file dependencies
// @dep_header javax_swing_undo_AbstractUndoableEdit

#include "javax/swing/undo/AbstractUndoableEdit.h"

#ifndef _JC_javax_swing_text_AbstractDocument__24ElementEdit_H_
#define _JC_javax_swing_text_AbstractDocument__24ElementEdit_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_text_Element$object;

// Typedefs
typedef struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$sub_refs	_jc_javax_swing_text_AbstractDocument__24ElementEdit$sub_refs;
typedef struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$sub_nonrefs	_jc_javax_swing_text_AbstractDocument__24ElementEdit$sub_nonrefs;
typedef struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$refs	_jc_javax_swing_text_AbstractDocument__24ElementEdit$refs;
typedef struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$nonrefs	_jc_javax_swing_text_AbstractDocument__24ElementEdit$nonrefs;
typedef struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$object	_jc_javax_swing_text_AbstractDocument__24ElementEdit$object;

typedef struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$fields_struct	_jc_javax_swing_text_AbstractDocument__24ElementEdit$fields_struct;
typedef const struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$vmethods	_jc_javax_swing_text_AbstractDocument__24ElementEdit$vmethods;
typedef const struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$vtable	_jc_javax_swing_text_AbstractDocument__24ElementEdit$vtable;
typedef const struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$vtype	_jc_javax_swing_text_AbstractDocument__24ElementEdit$vtype;

// Class fields structure
struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_text_AbstractDocument__24ElementEdit$fields_struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$class_fields;

// Constructors
extern void _jc_javax_swing_text_AbstractDocument__24ElementEdit$method$_init$6bf517a1d9ac8e3f(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$object *, struct _jc_object *, jint, struct _jc_object_array *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_object_array *_jc_javax_swing_text_AbstractDocument__24ElementEdit$method$getChildrenAdded$d6a053e473b11ce8(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_javax_swing_text_AbstractDocument__24ElementEdit$method$getChildrenRemoved$217236fae35b7e62(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_text_AbstractDocument__24ElementEdit$method$getElement$9ded1b90e4e688d5(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_text_AbstractDocument__24ElementEdit$method$getIndex$71a8f9126346f049(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_AbstractDocument__24ElementEdit$method_info$getChildrenAdded$d6a053e473b11ce8;
extern _jc_method _jc_javax_swing_text_AbstractDocument__24ElementEdit$method_info$getChildrenRemoved$217236fae35b7e62;
extern _jc_method _jc_javax_swing_text_AbstractDocument__24ElementEdit$method_info$getElement$9ded1b90e4e688d5;
extern _jc_method _jc_javax_swing_text_AbstractDocument__24ElementEdit$method_info$getIndex$71a8f9126346f049;

// Virtual methods structure
struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$vmethods {
	_jc_object_array	*(*getChildrenAdded$d6a053e473b11ce8)(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*getChildrenRemoved$217236fae35b7e62)(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getElement$9ded1b90e4e688d5)(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$object *) _JC_JCNI_ATTR;
	jint	(*getIndex$71a8f9126346f049)(_jc_env *, struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_undo_AbstractUndoableEdit$vmethods	javax_swing_undo_AbstractUndoableEdit;
	_jc_javax_swing_text_AbstractDocument__24ElementEdit$vmethods	javax_swing_text_AbstractDocument__24ElementEdit;
};

// Vtype
struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$vtype {
	_jc_type			type;
	_jc_javax_swing_text_AbstractDocument__24ElementEdit$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$sub_refs {
	struct _jc_object	*elem;
	_jc_object_array	*removed;
	_jc_object_array	*added;
};

// Reference instance fields (object)
struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$refs {
    _jc_javax_swing_text_AbstractDocument__24ElementEdit$sub_refs	javax_swing_text_AbstractDocument__24ElementEdit;
    _jc_javax_swing_undo_AbstractUndoableEdit$sub_refs	javax_swing_undo_AbstractUndoableEdit;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$sub_nonrefs {
	jint	index;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_undo_AbstractUndoableEdit$sub_nonrefs	javax_swing_undo_AbstractUndoableEdit;
    _jc_javax_swing_text_AbstractDocument__24ElementEdit$sub_nonrefs	javax_swing_text_AbstractDocument__24ElementEdit;
};

// Object instance structure
struct _jc_javax_swing_text_AbstractDocument__24ElementEdit$object {
	_jc_javax_swing_text_AbstractDocument__24ElementEdit$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_AbstractDocument__24ElementEdit$vtype	*vtype;
	_jc_javax_swing_text_AbstractDocument__24ElementEdit$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_AbstractDocument__24ElementEdit$vtype _jc_javax_swing_text_AbstractDocument__24ElementEdit$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_AbstractDocument__24ElementEdit, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_AbstractDocument__24ElementEdit$class_object;

#endif	/* _JC_javax_swing_text_AbstractDocument__24ElementEdit_H_ */
